@@ -222,7 +222,7 @@ int main(int argc, char *argv[])
 		 * file, ensures we're not going to be wasting resources in the privsep
 		 * process. */
 		dlog(LOG_DEBUG, 3, "Initializing privsep");
-		if (privsep_init() < 0) {
+		if (privsep_init(username, chrootdir) < 0) {
 			flog(LOG_INFO, "Failed to initialize privsep.");
 			exit(1);
 		}
@@ -284,6 +284,7 @@ int main(int argc, char *argv[])
 			flog(LOG_ERR, "unable to drop root privileges");
 			exit(1);
 		}
+		dlog(LOG_DEBUG, 3, "running as user: %s", username);
 	}
 
 	setup_ifaces(sock, ifaces);
@@ -294,6 +295,15 @@ int main(int argc, char *argv[])
 	unlink(daemon_pid_file_ident);
 	close(pid_fd);
 
+	if (ifaces)
+		free_ifaces(ifaces);
+
+	if (chrootdir)
+		free(chrootdir);
+
+	if (username)
+		free(username);
+
 	flog(LOG_INFO, "returning from radvd main");
 	log_close();
 
@@ -358,7 +368,7 @@ static void main_loop(int sock, struct Interface *ifaces, char const *conf_path)
 			ts.tv_sec = timeout / 1000;
 			ts.tv_nsec = (timeout - 1000 * ts.tv_sec) * 1000000;
 			tsp = &ts;
-			dlog(LOG_DEBUG, 1, "polling for %g seconds. Next iface is %s.", timeout / 1000.0,
+			dlog(LOG_DEBUG, 1, "polling for %g second(s). Next iface is %s.", timeout / 1000.0,
 			     next_iface_to_expire->props.name);
 		} else {
 			dlog(LOG_DEBUG, 1, "No iface is next. Polling indefinitely.");
@@ -382,8 +392,9 @@ static void main_loop(int sock, struct Interface *ifaces, char const *conf_path)
 				struct sockaddr_in6 rcv_addr;
 				struct in6_pktinfo *pkt_info = NULL;
 				unsigned char msg[MSG_SIZE_RECV];
+				unsigned char chdr[CMSG_SPACE(sizeof(struct in6_pktinfo)) + CMSG_SPACE(sizeof(int))];
 
-				len = recv_rs_ra(sock, msg, &rcv_addr, &pkt_info, &hoplimit);
+				len = recv_rs_ra(sock, msg, &rcv_addr, &pkt_info, &hoplimit, chdr);
 				if (len > 0 && pkt_info) {
 					process(sock, ifaces, msg, len, &rcv_addr, pkt_info, hoplimit);
 				} else if (!pkt_info) {
